@@ -1,4 +1,4 @@
-//@line 39 "/export/home/slave/ffslave/mozilla-1.9.1-solaris-sparc-nightly/build/browser/components/preferences/advanced.js"
+//@line 39 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/browser/components/preferences/advanced.js"
 
 // Load DownloadUtils module for convertByteUnits
 Components.utils.import("resource://gre/modules/DownloadUtils.jsm");
@@ -23,7 +23,11 @@ var gAdvancedPane = {
         advancedPrefs.selectedIndex = preference.value;
     }
 
-//@line 68 "/export/home/slave/ffslave/mozilla-1.9.1-solaris-sparc-nightly/build/browser/components/preferences/advanced.js"
+//@line 64 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/browser/components/preferences/advanced.js"
+    this.updateAppUpdateItems();
+    this.updateAutoItems();
+    this.updateModeItems();
+//@line 68 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/browser/components/preferences/advanced.js"
     this.updateOfflineApps();
   },
 
@@ -357,7 +361,104 @@ var gAdvancedPane = {
    *             iii 0/1/2   t         true   
    * 
    */
-//@line 499 "/export/home/slave/ffslave/mozilla-1.9.1-solaris-sparc-nightly/build/browser/components/preferences/advanced.js"
+//@line 402 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/browser/components/preferences/advanced.js"
+  updateAppUpdateItems: function () 
+  {
+    var aus = 
+        Components.classes["@mozilla.org/updates/update-service;1"].
+        getService(Components.interfaces.nsIApplicationUpdateService2);
+
+    var enabledPref = document.getElementById("app.update.enabled");
+    var enableAppUpdate = document.getElementById("enableAppUpdate");
+
+    enableAppUpdate.disabled = !aus.canCheckForUpdates || enabledPref.locked;
+  },
+
+  /**
+   * Enables/disables UI for "when updates are found" based on the values,
+   * and "locked" states of associated preferences.
+   */
+  updateAutoItems: function () 
+  {
+    var enabledPref = document.getElementById("app.update.enabled");
+    var autoPref = document.getElementById("app.update.auto");
+    
+    var updateModeLabel = document.getElementById("updateModeLabel");
+    var updateMode = document.getElementById("updateMode");
+    
+    var disable = enabledPref.locked || !enabledPref.value ||
+                  autoPref.locked;
+    updateModeLabel.disabled = updateMode.disabled = disable;
+  },
+
+  /**
+   * Enables/disables the "warn if incompatible extensions/themes exist" UI
+   * based on the values and "locked" states of various preferences.
+   */
+  updateModeItems: function () 
+  {
+    var enabledPref = document.getElementById("app.update.enabled");
+    var autoPref = document.getElementById("app.update.auto");
+    var modePref = document.getElementById("app.update.mode");
+    
+    var warnIncompatible = document.getElementById("warnIncompatible");
+    
+    var disable = enabledPref.locked || !enabledPref.value || autoPref.locked ||
+                  !autoPref.value || modePref.locked;
+    warnIncompatible.disabled = disable;
+  },
+
+  /**
+   * Stores the value of the app.update.mode preference, which is a tristate
+   * integer preference.  We store the value here so that we can properly
+   * restore the preference value if the UI reflecting the preference value
+   * is in a state which can represent either of two integer values (as
+   * opposed to only one possible value in the other UI state).
+   */
+  _modePreference: -1,
+
+  /**
+   * Reads the app.update.mode preference and converts its value into a
+   * true/false value for use in determining whether the "Warn me if this will
+   * disable extensions or themes" checkbox is checked.  We also save the value
+   * of the preference so that the preference value can be properly restored if
+   * the user's preferences cannot adequately be expressed by a single checkbox.
+   *
+   * app.update.modee         Checkbox State    Meaning
+   * 0                        Unchecked         Do not warn
+   * 1                        Checked           Warn if there are incompatibilities
+   * 2                        Checked           Warn if there are incompatibilities,
+   *                                            or the update is major.
+   */
+  readAddonWarn: function ()
+  {
+    var preference = document.getElementById("app.update.mode");
+    var doNotWarn = preference.value != 0;
+    gAdvancedPane._modePreference = doNotWarn ? preference.value : 1;
+    return doNotWarn;
+  },
+
+  /**
+   * Converts the state of the "Warn me if this will disable extensions or
+   * themes" checkbox into the integer preference which represents it,
+   * returning that value.
+   */
+  writeAddonWarn: function ()
+  {
+    var warnIncompatible = document.getElementById("warnIncompatible");
+    return !warnIncompatible.checked ? 0 : gAdvancedPane._modePreference;
+  },
+
+  /**
+   * Displays the history of installed updates.
+   */
+  showUpdates: function ()
+  {
+    var prompter = Components.classes["@mozilla.org/updates/update-prompt;1"]
+                             .createInstance(Components.interfaces.nsIUpdatePrompt);
+    prompter.showUpdateHistory(window);
+  },
+//@line 499 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/browser/components/preferences/advanced.js"
 
   /**
    * The Extensions checkbox and button are disabled only if the enable Addon
@@ -427,7 +528,7 @@ var gAdvancedPane = {
                                         "chrome://pippki/content/device_manager.xul",
                                         "", null);
   }
-//@line 569 "/export/home/slave/ffslave/mozilla-1.9.1-solaris-sparc-nightly/build/browser/components/preferences/advanced.js"
+//@line 569 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/browser/components/preferences/advanced.js"
   ,
 
   // SYSTEM DEFAULTS
@@ -473,5 +574,5 @@ var gAdvancedPane = {
       psvc.alert(window, promptTitle, promptMessage);
     }
   }
-//@line 615 "/export/home/slave/ffslave/mozilla-1.9.1-solaris-sparc-nightly/build/browser/components/preferences/advanced.js"
+//@line 615 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/browser/components/preferences/advanced.js"
 };
